@@ -50,9 +50,10 @@ const addWatcher=function (path){
     watcher.on('all', (eventType, filename) => {
         if(watcher.ready){
             logger.info(filename + " is changed  try to restart server ..");
-            Object.keys(cluster.workers).forEach((id) => {
-                cluster.workers[id].process.kill();
-            });
+            //Object.keys(cluster.workers).forEach((id) => {
+              //  cluster.workers[id].process.kill();
+            //});
+            process.exit(0);
         }
     });
     //watchers.push(watcher);
