@@ -32,11 +32,11 @@ exports.serve = function (nylon_path, port) {
         work_dir: work_dir,
         nylon_path: nylon_path,
         server_port: port,
-        
-        req:{
-            
+
+        req: {
+
         },
-        res:{
+        res: {
 
         }
     };
@@ -45,53 +45,53 @@ exports.serve = function (nylon_path, port) {
 
         cluster.fork();
         cluster.on('exit', (worker, code, signal) => {
-            console.log("code::"+code);
-            console.log("signal::"+signal);
-            if(code!=255){
+            console.log("code::" + code);
+            console.log("signal::" + signal);
+            if (code != 255) {
                 cluster.fork();
                 logger.info('worker ' + worker.process.pid + ' died');
             }
-           
+
         });
-      //  cluster.on('online', (worker) => {
-            console.log(process.cwd());
-            watcher.addWatcher(process.cwd() + '/app');
-            watcher.addWatcher(process.cwd() + '/config');
-           // watcher.addWatcher(process.cwd() + '/ssl');
-            watcher.addWatcher(nylon.nylon_path + '/java/libs');
-            watcher.addWatcher(nylon.nylon_path + '/java/nylon-report/dist');
-            watcher.addWatcher(nylon.nylon_path + '/java/nylon-utility/dist');
-            watcher.addWatcher(nylon.nylon_path + '/lib');
-     //   });
+        //  cluster.on('online', (worker) => {
+        console.log(process.cwd());
+        watcher.addWatcher(process.cwd() + '/app');
+        watcher.addWatcher(process.cwd() + '/config');
+        // watcher.addWatcher(process.cwd() + '/ssl');
+        watcher.addWatcher(nylon.nylon_path + '/java/libs');
+        watcher.addWatcher(nylon.nylon_path + '/java/nylon-report/dist');
+        watcher.addWatcher(nylon.nylon_path + '/java/nylon-utility/dist');
+        watcher.addWatcher(nylon.nylon_path + '/lib');
+        //   });
 
 
     } else {
 
-      //  nylon.server_key = fs.readFileSync(nylon.work_dir + "/ssl/server.key");
-       // nylon.server_cert = fs.readFileSync(nylon.work_dir + "/ssl/server.crt");
+        //  nylon.server_key = fs.readFileSync(nylon.work_dir + "/ssl/server.key");
+        // nylon.server_cert = fs.readFileSync(nylon.work_dir + "/ssl/server.crt");
 
-       // nylon.req.server_key=nylon.server_key;
-        nylon.server_key="1234560";
+        // nylon.req.server_key=nylon.server_key;
+        nylon.server_key = "1234560";
         var app = application(nylon);
         var server = null;
 
 
-       /* var options = {
-            key: nylon.server_key, //fs.readFileSync(work_dir + "/ssl/server.key"),
-            cert: nylon.server_cert, // fs.readFileSync(work_dir + "/ssl/server.crt"),
-            spdy: {
-                protocols: ['h2', 'spdy/3.1', 'spdy/3', 'spdy/2', 'http/1.1', 'http/1.0'],
-                plain: false,
-                'x-forwarded-for': true,
-                connection: {
-                    windowSize: 1024 * 1024,
-                    autoSpdy31: false
-                }
-            }
-        };*/
+        /* var options = {
+             key: nylon.server_key, //fs.readFileSync(work_dir + "/ssl/server.key"),
+             cert: nylon.server_cert, // fs.readFileSync(work_dir + "/ssl/server.crt"),
+             spdy: {
+                 protocols: ['h2', 'spdy/3.1', 'spdy/3', 'spdy/2', 'http/1.1', 'http/1.0'],
+                 plain: false,
+                 'x-forwarded-for': true,
+                 connection: {
+                     windowSize: 1024 * 1024,
+                     autoSpdy31: false
+                 }
+             }
+         };*/
 
 
-     //    server = http2.createServer(options, app);
+        //    server = http2.createServer(options, app);
         server = http.createServer(app);
 
 
@@ -107,9 +107,13 @@ exports.serve = function (nylon_path, port) {
             logger.error(err);
             process.exit(1);
         });
-       
-        process.on("SIGINT",function(){
-            process.exit(-1);
+
+        process.on("SIGINT", function () {
+            for (worker in cluster.workers) {
+                cluster.workers[worker].kill();
+            }
+           // process.exit(0);
+            process.exit(0);
         });
 
         module.exports = app;
